@@ -22,7 +22,8 @@ class DocToPng(object):
     def multiple_doc_to_png_by_file_dir(doc_dir, libreoffice_version=7.0, img_dir=None, zoom_x=8, zoom_y=8,
                                         rotation_angle=0):
         try:
-            status, result = DocToPdf.multiple_doc_to_pdf_by_file_dir(doc_dir, pdf_dir="/tmp/", libreoffice_version=libreoffice_version)
+            status, result = DocToPdf.multiple_doc_to_pdf_by_file_dir(doc_dir, pdf_dir="/tmp/",
+                                                                      libreoffice_version=libreoffice_version)
 
             if status != SUCCESS_STATUS:
                 return status, result
@@ -36,7 +37,8 @@ class DocToPng(object):
     def multiple_doc_to_png_by_file_list(doc_path_list=[], libreoffice_version=7.0, img_dir=None, zoom_x=8, zoom_y=8,
                                          rotation_angle=0):
         try:
-            status, result = DocToPdf.multiple_doc_to_pdf_by_file_list(doc_path_list, pdf_dir="/tmp/", libreoffice_version=libreoffice_version)
+            status, result = DocToPdf.multiple_doc_to_pdf_by_file_list(doc_path_list, pdf_dir="/tmp/",
+                                                                       libreoffice_version=libreoffice_version)
 
             if status != SUCCESS_STATUS:
                 return status, result
